Calculate Kling--Gupta Efficiency (KGE) (or modified KGE ('KGE)) between modeled (simulated) and observed values.
GOF_kling_gupta_efficiency(mod, obs, modified = FALSE, na.rm = TRUE)Value of computed KGE or 'KGE.
'numeric' vector. Modeled or simulated values. Must be same length as obs.
'numeric' vector. Observed or comparison values. Must be same length as mod.
'boolean' TRUE or FALSE. Should the KGE calculation use the original
variability ratio in the standard deviations (see Gupta and others, 2009) (modified = FALSE)
or the modified variability ratio in the coefficient of variations (see Kling and others, 2012)
(modified = TRUE). Default is FALSE.
'boolean' TRUE or FALSE. Should NA values be removed before computing. If any
NA values are present in mod or obs, the ith position from each will be removed before
calculating. If NA values are present and na.rm = FALSE, then function will return NA.
Default is TRUE.
Kling, H., Fuchs, M. and Paulin, M., 2012. Runoff conditions in the upper Danube basin under an
ensemble of climate change scenarios: Journal of Hydrology, v. 424-425, p. 264-277.
[Also available at https://doi.org/10.1016/j.jhydrol.2012.01.011.]
Gupta, H.V., Kling, H., Yilmaz, K.K., and Martinez, G.G., 2009. Decomposition of the mean
squared error and NSE performance criteria: Implications for improving hydrological modelling:
Journal of Hydrology, v. 377, no.1-2, p. 80-91.
[Also available at https://doi.org/10.1016/j.jhydrol.2009.08.003.]
GOF_kling_gupta_efficiency(
mod = example_mod$streamflow_cfs, obs = example_obs$streamflow_cfs
)
Run the code above in your browser using DataLab