Learn R Programming

HyMETT (version 1.1.3)

GOF_mean_error: Calculates mean error.

Description

Calculates mean error between modeled (simulated) and observed values. Error is defined as modeled minus observed.

Usage

GOF_mean_error(mod, obs, na.rm = TRUE)

Value

Value of calculated mean error.

Arguments

mod

'numeric' vector. Modeled or simulated values. Must be same length as obs.

obs

'numeric' vector. Observed or comparison values. Must be same length as mod.

na.rm

'boolean' TRUE or FALSE. Should NA values be removed before computing. If any NA values are present in mod or obs, the ith position from each will be removed before calculating. If NA values are present and na.rm = FALSE, then function will return NA. Default is TRUE.

Details

Values returned are in units of input data.

Examples

Run this code
GOF_mean_error(mod = example_mod$streamflow_cfs, obs = example_obs$streamflow_cfs)

Run the code above in your browser using DataLab