'numeric' value of computed root-mean-square error (RMSE) or
normalized root-mean-square error (NRMSE)
Arguments
mod
'numeric' vector. Modeled or simulated values. Must be same length as obs.
obs
'numeric' vector. Observed or comparison values. Must be same length as mod.
normalize
'character' value. Option to normalize the root-mean-square error (NRMSE) by
several normalizing options. Default is 'none'(no normalizing). RMSE is
returned. 'mean'. RMSE is normalized by the mean of obs. 'range'. RMSE is normalized by the range (max - min) of obs. 'stdev'. RMSE is normalized by the standard deviation of obs. 'iqr-#'. RMSE is normalized by the inter-quartile range of obs, with distribution type
(see stats::quantile function) indicated by integer number (for example "iqr-8").
If no type specified, default type is iqr-7, the quantile function default.
na.rm
'boolean' TRUE or FALSE. Should NA values be removed before computing. If any
NA values are present in mod or obs, the ith position from each will be removed before
calculating. If NA values are present and na.rm = FALSE, then function will return NA.
Default is TRUE.