Calculate Volumetric efficiency (VE) between modeled (simulated) and observed values. VE is defined as the fraction of water delivered at the proper time (Criss and Winston, 2008).
GOF_volumetric_efficiency(mod, obs, na.rm = TRUE)Value of computed Volumetric efficiency.
'numeric' vector. Modeled or simulated values. Must be same length as obs.
'numeric' vector. Observed or comparison values. Must be same length as mod.
'boolean' TRUE or FALSE. Should NA values be removed before computing. If any
NA values are present in mod or obs, the ith position from each will be removed before
calculating. If NA values are present and na.rm = FALSE, then function will return NA.
Default is TRUE.
Volumetric efficiency was proposed in order to circumvent some problems associated to the
Nash--Sutcliffe efficiency. It ranges from 0 to 1 and represents the fraction of water
delivered at the proper time; its compliment represents the fractional volumetric mismatch
(Criss and Winston, 2008).
Criss, R.E. and Winston, W.E., 2008, Do Nash values have value? Discussion and alternate
proposals: Hydrological Processes, v. 22, p. 2723-2725.
[Also available at https://doi.org/10.1002/hyp.7072.]
Zambrano-Bigiarini, M., 2020, hydroGOF: Goodness-of-fit functions for comparison of simulated and observed hydrological time series R package version 0.4-0. accessed September 16, 2020, at https://github.com/hzambran/hydroGOF. [Also available at https://doi.org/10.5281/zenodo.839854.]
GOF_volumetric_efficiency(
mod = example_mod$streamflow_cfs, obs = example_obs$streamflow_cfs
)
Run the code above in your browser using DataLab