Learn R Programming

HyMETT (version 1.1.3)

HyMETT-package: Hydrologic Model Evaluation and Time-series Tools

Description

Facilitates the analysis and evaluation of hydrologic model output and time-series data with functions focused on comparison of modeled (simulated) and observed data, period-of-record statistics, and trends.

Arguments

Details

Please see tools:::Rd_expr_doi("10.5066/P9FNXEWI") for more details.