POR_apply_annual_lowflow_stats: Calculate 10-year and 2-year return periods of a streamflow time series
Description
Calculates 10-year and 2-year return periods of a streamflow time series from
annual n-day low streamflow values and returns a data.frame in the format of other
period-of-record (POR) metrics.
Usage
POR_apply_annual_lowflow_stats(annual_min)
Value
data.frame with 10-year and 2-year return period of n-day streamflows.
Arguments
annual_min
'numeric' vector or data.frame. Vector or data.frame with columns of annual
n-day minimum streamflows.
Details
POR_apply_POR_lowflow_metrics is a helper function that applies the POR_calc_lp3_quantile
function to the data.frame of n-day moving averages, which can be computed during pre-processing
step using preproc_precondition_data and calc_annual_flow_stats, or preproc_main for
both observed and modeled data. This function returns a data.frame with the 10-year and 2-year
return period streamflows for each n-day low streamflow in the input data.frame.