POR_deseasonalize: Removes seasonal trends from a daily or monthly time series.
Description
Removes seasonal trends from a daily or monthly time series. Daily data are
deseasonalized by subtracting monthly mean values. Monthly data are deseasonalized by
subtracting mean monthly values.
'data.frame'. Optional data.frame input, with columns containing Date and value.
Column names are specified as strings in the corresponding parameter. Default is NULL.
Date
'numeric' vector of Dates corresponding to each value when data = NULL, or
'character' string identifying Date column name when data is specified.
value
'numeric' vector of values (often streamflow) when data = NULL, or
'character' string identifying value column name when data is specified.
(assumed to be daily or monthly).
time_step
'character' value. Either "daily" or "monthly".
Details
The deseasonalize function removes seasonal trends from a daily or monthly time series
and returns a deseasonalized time series, which can be used in the POR_calc_AR1 function.