Calculates various metrics that describe the distribution of a time series of streamflow, which can be of any time step.
POR_distribution_metrics(value, quantile_type = 8, na.rm = TRUE)A data.frame with FDC quantiles, and distribution metrics. See Details. This function calculates various metrics that describe the distribution of a time series of streamflow, which can be of any time step.
'numeric' vector of values (assumed to be streamflow) at any time step.
'numeric' value. The distribution type used in the stats::quantile
function. Default is 8 (median-unbiased regardless of distribution). Other
types common in hydrology are 6 (Weibull) or 9 (unbiased for normal distributions).
'boolean' TRUE or FALSE. Should NA values be removed before computing. If
NA values are present and na.rm = FALSE, then function will return NAs. Default is TRUE.
Metrics computed include:
p_nFlow-duration curve (FDC) percentile where n = 1, 5, 10, 25, 50, 75, 90, 95, and 99
POR_meanPeriod of record mean
POR_sdPeriod of record standard deviation
POR_cvPeriod of record coefficient of variation
POR_minPeriod of record minimum
POR_maxPeriod of record maximum
LCVL-moment coefficient of variation
LskewL-moment skewness
LkurtosisL-moment kurtosis
Farmer, W.H., Archfield, S.A., Over, T.M., Hay, L.E., LaFontaine, J.H., and Kiang, J.E., 2014, A comparison of methods to predict historical daily streamflow time series in the southeastern United States: U.S. Geological Survey Scientific Investigations Report 2014–5231, 34 p. [Also available at https://doi.org/10.3133/sir20145231.]
Asquith, W.H., Kiang, J.E., and Cohn, T.A., 2017, Application of at-site peak-streamflow frequency analyses for very low annual exceedance probabilities: U.S. Geological Survey Scientific Investigation Report 2017–5038, 93 p. [Also available at https://doi.org/10.3133/sir20175038.]
Asquith, W.H., 2021, lmomco---L-moments, censored L-moments, trimmed L-moments,
L-comoments, and many distributions. R package version 2.3.7, Texas Tech University,
Lubbock, Texas.
lmoms, quantile
POR_distribution_metrics(value = example_obs$streamflow_cfs)
Run the code above in your browser using DataLab