Calculate benchmark Kling--Gupta efficiency (KGE) values from daily observed time-series data
benchmark_KGE_DOY(obs_preproc)A data.frame with columns "KGE_DOY_mean" and "KGE_DOY_median".
'data.frame' of daily observational data, preprocessed as output from
preproc_precondition_data or preproc_main "daily".
This function calculates a "benchmark" KGE value (see Knoben and others, 2020) from a daily
observed data time-series. First, the interannual mean and median is calculated for each day of
the calendar year. Next, the interannual mean and median values are joined to each corresponding
day in the observation time series. Finally, a KGE value (GOF_kling_gupta_efficiency) is
calculated comparing the mean or median value repeated time series to the daily observational
time series. These benchmark KGE values can be used as comparisons for modeled (simulated)
calibration results.
Knoben, W.J.M, Freer, J.E., Peel, M.C., Fowler, K.J.A, Woods, R.A., 2020. A Brief Analysis of
Conceptual Model Structure Uncertainty Using 36 Models and 559 Catchments: Water Resources
Research, v. 56.
[Also available at https://doi.org/10.1029/2019WR025975.]
benchmark_KGE_DOY(obs_preproc = example_preproc)
Run the code above in your browser using DataLab