Learn R Programming

HyMETT (version 1.1.3)

calc_qpearsonIII: Quantile of Pearson Type III distribution

Description

Quantile of Pearson Type III distribution

Usage

calc_qpearsonIII(p, mean = 0, sd = 1, skew = 0)

Value

Quantiles for the described distribution

Arguments

p

Vector of non-exceedance probabilities, between 0 and 1, to calculate quantiles.

mean

Vector of means of the distribution of the data.

sd

Vector of standard deviation of the distribution of the data.

skew

Vector of skewness of the distribution of the data.

Details

calc_qpearsonIII and calc_qlpearsonIII are functions to fit a log-Pearson type III distribution from a given mean, standard deviation, and skew. This source code is replicated, unchanged, from the swmrBase package in order to reduce the dependency on that package.

References

Asquith, W.H., Kiang, J.E., and Cohn, T.A., 2017, Application of at-site peak-streamflow frequency analyses for very low annual exceedance probabilities: U.S. Geological Survey Scientific Investigation Report 2017–5038, 93 p. [Also available at https://doi.org/10.3133/sir20175038.]

Lorenz, D.L., 2015, smwrBase—An R package for managing hydrologic data, version 1.1.1: U.S. Geological Survey Open-File Report 2015–1202, 7 p.
[Also available at https://doi.org/10.3133/ofr20151202.]

Examples

Run this code
calc_qpearsonIII(0.1)

Run the code above in your browser using DataLab